class Mesto:
    """Objekt pro zapouzdření informací o městě, obecně obci.."""
    def __init__(self, nazev, oznaceni):
        self.nazev = nazev
        self.oznaceni = oznaceni

    def IsEqual(self, mesto):
        """ Porovnáme dva mesto a pokud jsou schodné vracíme True.. """
        if self.nazev == mesto.nazev and self.oznaceni == mesto.oznaceni:
            return True
        return False


mestos = []
mestos.append(Mesto("Praha", "AA"))
mestos.append(Mesto("Brno", "BI"))
mestos.append(Mesto("Ostrava", "OS"))
mestos.append(Mesto("Plzeň", "PL"))
mestos.append(Mesto("Liberec", "LI"))
mestos.append(Mesto("Olomouc", "OC"))
mestos.append(Mesto("České Budějovice", "ČB"))
mestos.append(Mesto("Ústí nad Labem", "ÚL"))
mestos.append(Mesto("Hradec Králov", "HK"))
mestos.append(Mesto("Pardubice", "PA"))
mestos.append(Mesto("Zlín", "ZL"))
mestos.append(Mesto("Havířov", "HA"))
mestos.append(Mesto("Kladno", "KL"))
mestos.append(Mesto("Most", "MO"))
mestos.append(Mesto("Opava", "OP"))
mestos.append(Mesto("Frýdek-Místek", "FM"))
mestos.append(Mesto("Karviná", "KA"))
mestos.append(Mesto("Jihlava", "JI"))
mestos.append(Mesto("Teplice", "TE"))
mestos.append(Mesto("Děčín", "DE"))
mestos.append(Mesto("Karlovy Vary", "KV"))
mestos.append(Mesto("Chomutov", "CH"))
mestos.append(Mesto("Jablonec nad Nisou", "JN"))
mestos.append(Mesto("Prostějov", "PJ"))
mestos.append(Mesto("Přerov", "PŘ"))
mestos.append(Mesto("Mladá Boleslav", "MB"))
mestos.append(Mesto("Třebíš", "TŘ"))
mestos.append(Mesto("Česká Lípa", "ČL"))
mestos.append(Mesto("Třinec", "TŘ"))
mestos.append(Mesto("Tábor", "TÁ"))
mestos.append(Mesto("Znojmo", "ZN"))
mestos.append(Mesto("Příbram", "PŘ"))
mestos.append(Mesto("Cheb", "CE"))
mestos.append(Mesto("Orlová", "OR"))
mestos.append(Mesto("Kolín", "KO"))
mestos.append(Mesto("Trutnov", "TR"))
mestos.append(Mesto("Písek", "PÍ"))
mestos.append(Mesto("Kroměříž", "KM"))
mestos.append(Mesto("Šumperk", "ŠU"))
mestos.append(Mesto("Vsetín", "VS"))
mestos.append(Mesto("Valašské Meziříčí", "VM"))
mestos.append(Mesto("Litvínov", "LI"))
mestos.append(Mesto("Uherské Hradiště", "UH"))
mestos.append(Mesto("Hodnotnín", "HO"))
mestos.append(Mesto("Český Těšín", "ČT"))
mestos.append(Mesto("Břeclav", "BŘ"))
mestos.append(Mesto("Krnov", "KR"))
mestos.append(Mesto("Litoměřice", "LI"))
mestos.append(Mesto("Sokolov", "SO"))
mestos.append(Mesto("Nový Jičín", "NJ"))
mestos.append(Mesto("Havlíčkův Brod", "HB"))
mestos.append(Mesto("Chrudim", "CU"))
mestos.append(Mesto("Strakonice", "ST"))
mestos.append(Mesto("Kopřivnice", "KO"))
mestos.append(Mesto("Klatovy", "KL"))
mestos.append(Mesto("Žďár nad Sázavou", "ŽS"))
mestos.append(Mesto("Bohumín", "BO"))
mestos.append(Mesto("Jindřichův Hradec", "JH"))
mestos.append(Mesto("Vyškov", "VY"))
mestos.append(Mesto("Blansko", "BL"))
mestos.append(Mesto("Kutná Hora", "KH"))
mestos.append(Mesto("Náchod", "NÁ"))
mestos.append(Mesto("Jirkov", "JI"))
mestos.append(Mesto("Mělník", "MĚ"))
mestos.append(Mesto("Žatec", "ŽA"))
mestos.append(Mesto("Hranice", "HR"))
mestos.append(Mesto("Beroun", "BE"))
mestos.append(Mesto("Louny", "LO"))
mestos.append(Mesto("Otrokovice", "OT"))
mestos.append(Mesto("Kralupy nad Vltavou", "KV"))
mestos.append(Mesto("Kadaň", "KA"))
mestos.append(Mesto("Brandýs nad Laběm", "BL"))
mestos.append(Mesto("Ostrov", "OS"))
mestos.append(Mesto("Svitavy", "SV"))
mestos.append(Mesto("Bruntál", "BR"))
mestos.append(Mesto("Uherský Brod", "UB"))
mestos.append(Mesto("Rožnov pod Radhošťem", "RK"))
mestos.append(Mesto("Jičín", "JI"))
mestos.append(Mesto("Rakovník", "RA"))
mestos.append(Mesto("Neratovice", "NE"))
mestos.append(Mesto("Benešov", "BE"))
mestos.append(Mesto("Pelhřimov", "PE"))
mestos.append(Mesto("Dvůr Králové nad Labem", "DK"))
mestos.append(Mesto("Bilina", "BI"))
mestos.append(Mesto("Varnsdorf", "VA"))
mestos.append(Mesto("Slaný", "SL"))
mestos.append(Mesto("Klášterec nad Ohří", "KO"))
mestos.append(Mesto("Mariánské Lázně", "ML"))
mestos.append(Mesto("Nymburk", "NY"))
mestos.append(Mesto("Ústí nad Orlicí", "ÚO"))
mestos.append(Mesto("Turnov", "TU"))
mestos.append(Mesto("Chodov", "CV"))
mestos.append(Mesto("Rokycany", "RO"))
mestos.append(Mesto("Hlučín", "KHL"))
mestos.append(Mesto("Poděbrady", "PO"))
mestos.append(Mesto("Zábřeh", "ZÁ"))
mestos.append(Mesto("Šternberk", "ŠT"))
mestos.append(Mesto("Krupka", "KR"))
mestos.append(Mesto("Říčany", "ŘÍ"))
mestos.append(Mesto("Český Krumlov", "ČK"))
mestos.append(Mesto("Roudnice nad Labem", "RL"))
mestos.append(Mesto("Aš", "AŠ"))
mestos.append(Mesto("Tachov", "TA"))
mestos.append(Mesto("Vrchlabí", "VR"))
mestos.append(Mesto("Jaroměř", "JA"))
mestos.append(Mesto("Vysoké Mýto", "VM"))
mestos.append(Mesto("Nový Bor", "NB"))
mestos.append(Mesto("Holešov", "HO"))
mestos.append(Mesto("Vlašim", "VL"))
mestos.append(Mesto("Uničov", "UN"))
mestos.append(Mesto("Jeseník", "JE"))
mestos.append(Mesto("Velké Meziříčí", "VM"))
mestos.append(Mesto("Čelákovce", "ČE"))
mestos.append(Mesto("Kyjov", "KY"))
mestos.append(Mesto("Veselí nad Moravou", "VÍ"))
mestos.append(Mesto("Boskovice", "BO"))
mestos.append(Mesto("Prachatice", "PE"))
mestos.append(Mesto("Rychnov nad Kněžnou", "RK"))
mestos.append(Mesto("Sušice", "SU"))
mestos.append(Mesto("Rumburk", "RU"))
mestos.append(Mesto("Domažlice", "DO"))
mestos.append(Mesto("Frenštát pod Radhoštěm", "FR"))
mestos.append(Mesto("Humpolec", "HU"))
mestos.append(Mesto("Kuřim", "KU"))
mestos.append(Mesto("Moravská Třebová", "MT"))
mestos.append(Mesto("Nové Město na Moravě", "NM"))
mestos.append(Mesto("Litomyšl", "LI"))
mestos.append(Mesto("Lanškroun", "LA"))
mestos.append(Mesto("Čáslav", "ČA"))
mestos.append(Mesto("Hlinsko", "HL"))
mestos.append(Mesto("Litovel", "LI"))
mestos.append(Mesto("Nové Město nad Metují", "NM"))
mestos.append(Mesto("Frýdlant nad Ostravicí", "FO"))
mestos.append(Mesto("Milovice", "MI"))
mestos.append(Mesto("Mohelnice", "MO"))
mestos.append(Mesto("Ivančice", "IV"))
mestos.append(Mesto("Chotěboř", "CŘ"))
mestos.append(Mesto("Nová Paka", "NP"))
mestos.append(Mesto("Přelouč", "PŘ"))
mestos.append(Mesto("Štětí", "ŠT"))
mestos.append(Mesto("Polička", "PO"))
mestos.append(Mesto("Hořice", "HO"))
mestos.append(Mesto("Choceň", "OC"))
mestos.append(Mesto("Lovosice", "LO"))
mestos.append(Mesto("Milevsko", "MI"))
mestos.append(Mesto("Lysá nad Labem", "LL"))
mestos.append(Mesto("Semily", "SE"))
mestos.append(Mesto("Duchov", "DU"))
mestos.append(Mesto("Příbor", "PŘ"))
mestos.append(Mesto("Tišnov", "TI"))
mestos.append(Mesto("Třeboň", "TŘ"))
mestos.append(Mesto("Dobříč", "DO"))
mestos.append(Mesto("Rýmařov", "RÝ"))
mestos.append(Mesto("Bystřice nad Pernštejnem", "BP"))
mestos.append(Mesto("Červený Kostelec", "ČK"))
mestos.append(Mesto("Bystřice pod Hostýnem", "BH"))
mestos.append(Mesto("Nejdek", "NE"))
mestos.append(Mesto("Mnichovo Hradiště", "MH"))
mestos.append(Mesto("Lipník nad Bečvou", "LB"))
mestos.append(Mesto("Týn nad Vltavou", "TV"))
mestos.append(Mesto("Dubí", "DU"))
mestos.append(Mesto("Stříbro", "ST"))
mestos.append(Mesto("Broumov", "BR"))
mestos.append(Mesto("Roztoky", "RO"))
mestos.append(Mesto("Vimperk", "VI"))

