import random

from pyranda.prijmeni import Prijmeni

class Prijmenis:
    """ Třída zapouzdřující chování obyčejného příjmení.. """
    def __init__(self):
        self.prijmenis = []
        self.dataInit()

    def GetRandomPrijmeni(self, pohlavi):
        index = random.randint(0, len(self.prijmenis) - 1)
        prijmeni= self.prijmenis[index]
        if pohlavi == 2:
            return prijmeni.nazev2 
        return prijmeni.nazev 

    def dataInit(self):
        self.prijmenis.append(Prijmeni("Novák", "Nováková")) 
        self.prijmenis.append(Prijmeni("Koudelka", "Koudelková")) 
        self.prijmenis.append(Prijmeni("Procházka", "Procházková")) 
        self.prijmenis.append(Prijmeni('Adamčík', 'Adamčíková'))
        self.prijmenis.append(Prijmeni('Adámek', 'Adámková'))
        self.prijmenis.append(Prijmeni('Adrián', 'Adriánová'))
        self.prijmenis.append(Prijmeni('Aizner', 'Aiznerová'))
        self.prijmenis.append(Prijmeni('Antalík', 'Antalíková'))
        self.prijmenis.append(Prijmeni('Antl', 'Antlová'))
        self.prijmenis.append(Prijmeni('Antončík', 'Antončíková'))
        self.prijmenis.append(Prijmeni('Antošík', 'Antošíková'))
        self.prijmenis.append(Prijmeni('Apolenář', 'Apolenářová'))
        self.prijmenis.append(Prijmeni('Astaloš', 'Astalošová'))
        self.prijmenis.append(Prijmeni('Ašenbryl', 'Ašenbrylová'))
        self.prijmenis.append(Prijmeni('Augustýn', 'Augustýnková'))
        self.prijmenis.append(Prijmeni('Bednář', 'Bednářová'))
        self.prijmenis.append(Prijmeni('Bubák', 'Bubáková'))
        self.prijmenis.append(Prijmeni('Babčák', 'Babčáková'))
        self.prijmenis.append(Prijmeni('Babin', 'Babincová'))
        self.prijmenis.append(Prijmeni('Bábor', 'Báborová'))
        self.prijmenis.append(Prijmeni('Babuka', 'Babuková'))
        self.prijmenis.append(Prijmeni('Badura', 'Badurová'))
        self.prijmenis.append(Prijmeni('Bachel', 'Bachelová'))
        self.prijmenis.append(Prijmeni('Bachman', 'Bachmannová'))
        self.prijmenis.append(Prijmeni('Bednařík', 'Bednaříková'))
        self.prijmenis.append(Prijmeni('Balada', 'Baladová'))
        self.prijmenis.append(Prijmeni('Balarin', 'Balarinová'))
        self.prijmenis.append(Prijmeni('Balatka', 'Balatková'))
        self.prijmenis.append(Prijmeni('Balcar', 'Balcarová'))
        self.prijmenis.append(Prijmeni('Balcarek', 'Balcarková'))
        self.prijmenis.append(Prijmeni('Bleša', 'Blešová'))
        self.prijmenis.append(Prijmeni('Baltair', 'Baltairová'))
        self.prijmenis.append(Prijmeni('Balvín', 'Balvínová'))
        self.prijmenis.append(Prijmeni('Caban', 'Cabanová'))
        self.prijmenis.append(Prijmeni('Cabuk', 'Cabuková'))
        self.prijmenis.append(Prijmeni('Cahlík', 'Cahlíková'))
        self.prijmenis.append(Prijmeni('Cakl', 'Caklová'))
        self.prijmenis.append(Prijmeni('Calta', 'Caltová'))
        self.prijmenis.append(Prijmeni('Cápík', 'Cápíková'))
        self.prijmenis.append(Prijmeni('Cardal', 'Cardalová'))
        self.prijmenis.append(Prijmeni('Cejhon', 'Cejhonová'))
        self.prijmenis.append(Prijmeni('Cekl', 'Ceklová'))
        self.prijmenis.append(Prijmeni('Celerin', 'Celerinová'))
        self.prijmenis.append(Prijmeni('Černý', 'Černá'))
        self.prijmenis.append(Prijmeni('Cibulka', 'Cibulková'))
        self.prijmenis.append(Prijmeni('Cidlík', 'Cidlíková'))
        self.prijmenis.append(Prijmeni('Císař', 'Císařová'))
        self.prijmenis.append(Prijmeni('Cigler', 'Ciglerová'))
        self.prijmenis.append(Prijmeni('Cichra', 'Cichrová'))
        self.prijmenis.append(Prijmeni('Cikl', 'Ciková'))
        self.prijmenis.append(Prijmeni('Ciprys', 'Ciprysová'))
        self.prijmenis.append(Prijmeni('Čagánek', 'Čagánková'))
        self.prijmenis.append(Prijmeni('Čapek', 'Čapková'))
        self.prijmenis.append(Prijmeni('Čapla', 'Čaplová'))
        self.prijmenis.append(Prijmeni('Černý', 'Černocká'))
        self.prijmenis.append(Prijmeni('Částka', 'Částková'))
        self.prijmenis.append(Prijmeni('Čavajda', 'Čavajdová'))
        self.prijmenis.append(Prijmeni('Čechal', 'Čechalová'))
        self.prijmenis.append(Prijmeni('Čepelík', 'Čepelíková'))
        self.prijmenis.append(Prijmeni('Červenka', 'Červenková'))
        self.prijmenis.append(Prijmeni('Černošek', 'Černošková'))
        self.prijmenis.append(Prijmeni('Červík', 'Červíková'))
        self.prijmenis.append(Prijmeni('Česák', 'Česáková'))
        self.prijmenis.append(Prijmeni('Češek', 'Češková'))
        self.prijmenis.append(Prijmeni('Češka', 'Češková'))
        self.prijmenis.append(Prijmeni('Čičela', 'Čičelová'))
        self.prijmenis.append(Prijmeni('Čokina', 'Čokinová'))
        self.prijmenis.append(Prijmeni('Čtvrtníček', 'Čtvrtníčková'))
        self.prijmenis.append(Prijmeni('Čubák', 'Čubáková'))
        self.prijmenis.append(Prijmeni('Čunek', 'Čunková'))
        self.prijmenis.append(Prijmeni('Cuřín', 'Cuřínová'))
        self.prijmenis.append(Prijmeni('Dratva', 'Dratvová'))
        self.prijmenis.append(Prijmeni('Dajka', 'Dajkvá'))
        self.prijmenis.append(Prijmeni('Dalibor', 'Daliborová'))
        self.prijmenis.append(Prijmeni('Damaška', 'Damašková'))
        self.prijmenis.append(Prijmeni('Dančák', 'Dančáková'))
        self.prijmenis.append(Prijmeni('Dandel', 'Dandelová'))
        self.prijmenis.append(Prijmeni('Danihel', 'Danihelková'))
        self.prijmenis.append(Prijmeni('Danko', 'Danková'))
        self.prijmenis.append(Prijmeni('Daráš', 'Darášová'))
        self.prijmenis.append(Prijmeni('Drábek', 'Drábková'))
        self.prijmenis.append(Prijmeni('Darebník', 'Derebníková'))
        self.prijmenis.append(Prijmeni('Darebníček', 'Darebníčková'))
        self.prijmenis.append(Prijmeni('Drtikol', 'Drtikolová'))
        self.prijmenis.append(Prijmeni('Drásal', 'Drásalová'))
        self.prijmenis.append(Prijmeni('David', 'Davidová'))
        self.prijmenis.append(Prijmeni('Dědek', 'Dětková'))
        self.prijmenis.append(Prijmeni('Dedek', 'Dedková'))
        self.prijmenis.append(Prijmeni('Didov', 'Didová'))
        self.prijmenis.append(Prijmeni('Dikoras', 'Dikorasová'))
        self.prijmenis.append(Prijmeni('Ditrich', 'Ditrichová'))
        self.prijmenis.append(Prijmeni('Djakov', 'Djakovová'))
        self.prijmenis.append(Prijmeni('Dlouhý', 'Dlouhá'))
        self.prijmenis.append(Prijmeni('Dobenčák', 'Dobenčáková'))
        self.prijmenis.append(Prijmeni('Dobrovský', 'Dobrovská'))
        self.prijmenis.append(Prijmeni('Dobřický', 'Dobřická'))
        self.prijmenis.append(Prijmeni('Dočekal', 'Dočekalová'))
        self.prijmenis.append(Prijmeni('Dohnalík', 'Dohnalíková'))
        self.prijmenis.append(Prijmeni('Donutil', 'Donutilová'))
        self.prijmenis.append(Prijmeni('Dokoupil', 'Dokoupilová'))
        self.prijmenis.append(Prijmeni('Domanín', 'Domanínová'))
        self.prijmenis.append(Prijmeni('Donáth', 'Donáthová'))

    def PrintAll():
        for prijmeni in self.prijmenis:
            print(prijmeni.nazev)
