import random

from pyranda.jmeno import Jmeno

class Jmenos:
    """ Třída zapouzdřující chování obyčejného jména.. """
    def __init__(self):
        self.jmenos1 = []
        self.jmenos2 = []
        self.dataInit()

    def GetRandomJmeno(self, pohlavi):
        if pohlavi == 1:
            index = random.randint(0, len(self.jmenos1) - 1)
            return self.jmenos1[index].nazev;
        if pohlavi == 2:
            index = random.randint(0, len(self.jmenos2) - 1)
            return self.jmenos2[index].nazev;
        return ""

    def dataInit(self):
        self.jmenos1.append(Jmeno("Aleš", 1, []))
        self.jmenos1.append(Jmeno("Alexandr", 1, []))
        self.jmenos1.append(Jmeno("Alois", 1, []))
        self.jmenos1.append(Jmeno("Antonín", 1, []))
        self.jmenos1.append(Jmeno("Bohdan", 1, []))
        self.jmenos1.append(Jmeno("Bohumil", 1, []))
        self.jmenos1.append(Jmeno("Boris", 1, []))
        self.jmenos1.append(Jmeno("Božřivoj", 1, []))
        self.jmenos1.append(Jmeno("Bronislav", 1, []))
        self.jmenos1.append(Jmeno("Ctibor", 1, []))
        self.jmenos1.append(Jmeno("Ctirad", 1, []))
        self.jmenos1.append(Jmeno("Cyril", 1, []))
        self.jmenos1.append(Jmeno("Čeněk", 1, []))
        self.jmenos1.append(Jmeno("Čestmír", 1, []))
        self.jmenos1.append(Jmeno("Dalibor", 1, []))
        self.jmenos1.append(Jmeno("Dan", 1, []))
        self.jmenos1.append(Jmeno("Daniel", 1, []))
        self.jmenos1.append(Jmeno("David", 1, []))
        self.jmenos1.append(Jmeno("Eduard", 1, []))
        self.jmenos1.append(Jmeno("Emil", 1, []))
        self.jmenos1.append(Jmeno("Erik", 1, []))
        self.jmenos1.append(Jmeno("Filip", 1, []))
        self.jmenos1.append(Jmeno("František", 1, []))
        self.jmenos1.append(Jmeno("Gregor", 1, []))
        self.jmenos1.append(Jmeno("Gustav", 1, []))
        self.jmenos1.append(Jmeno("Herbert", 1, []))
        self.jmenos1.append(Jmeno("Hubert", 1, []))
        self.jmenos1.append(Jmeno("Hynek", 1, []))
        self.jmenos1.append(Jmeno("Igor", 1, []))
        self.jmenos1.append(Jmeno("Ivana", 1, []))
        self.jmenos1.append(Jmeno("Ivoš", 1, []))
        self.jmenos1.append(Jmeno("Jakub", 1, []))
        self.jmenos1.append(Jmeno("Jan", 1, []))
        self.jmenos1.append(Jmeno("Jaroslav", 1, []))
        self.jmenos1.append(Jmeno("Jindřich", 1, []))
        self.jmenos1.append(Jmeno("Jiří", 1, []))
        self.jmenos1.append(Jmeno("Jonáš", 1, []))
        self.jmenos1.append(Jmeno("Josef", 1, ["Pepa"]))
        self.jmenos1.append(Jmeno("Kamil", 1, []))
        self.jmenos1.append(Jmeno("Karel", 1, []))
        self.jmenos1.append(Jmeno("Karel", 1, []))
        self.jmenos1.append(Jmeno("Krištof", 1, []))
        self.jmenos1.append(Jmeno("Květoslav", 1, []))
        self.jmenos1.append(Jmeno("Ladislav", 1, []))
        self.jmenos1.append(Jmeno("Leopold", 1, []))
        self.jmenos1.append(Jmeno("Leoš", 1, []))
        self.jmenos1.append(Jmeno("Libor", 1, []))
        self.jmenos1.append(Jmeno("Lubomír", 1, []))
        self.jmenos1.append(Jmeno("Luboš", 1, []))
        self.jmenos1.append(Jmeno("Lukáš", 1, []))
        self.jmenos1.append(Jmeno("Marcel", 1, []))
        self.jmenos1.append(Jmeno("Marek", 1, []))
        self.jmenos1.append(Jmeno("Martin", 1, []))
        self.jmenos1.append(Jmeno("Matěj", 1, []))
        self.jmenos1.append(Jmeno("Matouš", 1, []))
        self.jmenos1.append(Jmeno("Metoděj", 1, []))
        self.jmenos1.append(Jmeno("Michael", 1, []))
        self.jmenos1.append(Jmeno("Mikuláš", 1, []))
        self.jmenos1.append(Jmeno("Milan", 1, []))
        self.jmenos1.append(Jmeno("Miloslav", 1, []))
        self.jmenos1.append(Jmeno("Miloš", 1, []))
        self.jmenos1.append(Jmeno("Mirek", 1, []))
        self.jmenos1.append(Jmeno("Miroslav", 1, []))
        self.jmenos1.append(Jmeno("Mojmír", 1, []))
        self.jmenos1.append(Jmeno("Nikolas", 1, []))
        self.jmenos1.append(Jmeno("Oldřich", 1, []))
        self.jmenos1.append(Jmeno("Oliver", 1, []))
        self.jmenos1.append(Jmeno("Ondřej", 1, []))
        self.jmenos1.append(Jmeno("Oskar", 1, []))
        self.jmenos1.append(Jmeno("Otakar", 1, []))
        self.jmenos1.append(Jmeno("Otto", 1, []))
        self.jmenos1.append(Jmeno("Patrik", 1, []))
        self.jmenos1.append(Jmeno("Pavel", 1, []))
        self.jmenos1.append(Jmeno("Petr", 1, []))
        self.jmenos1.append(Jmeno("Prokop", 1, []))
        self.jmenos1.append(Jmeno("Přemysl", 1, []))
        self.jmenos1.append(Jmeno("Radek", 1, []))
        self.jmenos1.append(Jmeno("Radim", 1, []))
        self.jmenos1.append(Jmeno("Radomír", 1, []))
        self.jmenos1.append(Jmeno("Radovan", 1, []))
        self.jmenos1.append(Jmeno("René", 1, []))
        self.jmenos1.append(Jmeno("Richard", 1, []))
        self.jmenos1.append(Jmeno("Robert", 1, []))
        self.jmenos1.append(Jmeno("Robin", 1, []))
        self.jmenos1.append(Jmeno("Roman", 1, []))
        self.jmenos1.append(Jmeno("Řehoř", 1, []))
        self.jmenos1.append(Jmeno("Samuel", 1, []))
        self.jmenos1.append(Jmeno("Servác", 1, []))
        self.jmenos1.append(Jmeno("Simon", 1, []))
        self.jmenos1.append(Jmeno("Soběslav", 1, []))
        self.jmenos1.append(Jmeno("Stanislav", 1, []))
        self.jmenos1.append(Jmeno("Svatopluk", 1, []))
        self.jmenos1.append(Jmeno("Sylvestr", 1, []))
        self.jmenos1.append(Jmeno("Šimon", 1, []))
        self.jmenos1.append(Jmeno("Štefan", 1, []))
        self.jmenos1.append(Jmeno("Štěpán", 1, []))
        self.jmenos1.append(Jmeno("Tadeáš", 1, []))
        self.jmenos1.append(Jmeno("Tibor", 1, []))
        self.jmenos1.append(Jmeno("Tom", 1, []))
        self.jmenos1.append(Jmeno("Tomáš", 1, []))
        self.jmenos1.append(Jmeno("Tomáš", 1, []))
        self.jmenos1.append(Jmeno("Václav", 1, []))
        self.jmenos1.append(Jmeno("Valentýn", 1, []))
        self.jmenos1.append(Jmeno("Vavřinec", 1, []))
        self.jmenos1.append(Jmeno("Vendelín", 1, []))
        self.jmenos1.append(Jmeno("Věroslav", 1, []))
        self.jmenos1.append(Jmeno("Vilém", 1, []))
        self.jmenos1.append(Jmeno("Vít", 1, []))
        self.jmenos1.append(Jmeno("Vítek", 1, []))
        self.jmenos1.append(Jmeno("Vítězslav", 1, []))
        self.jmenos1.append(Jmeno("Vladan", 1, []))
        self.jmenos1.append(Jmeno("Vladimír", 1, ["Laďa"]))
        self.jmenos1.append(Jmeno("Vladislav", 1, []))
        self.jmenos1.append(Jmeno("Vlastimil", 1, []))
        self.jmenos1.append(Jmeno("Vojtěch", 1, []))
        self.jmenos1.append(Jmeno("Vratislav", 1, []))
        self.jmenos1.append(Jmeno("Waldemar", 1, []))
        self.jmenos1.append(Jmeno("Zbyněk", 1, []))
        self.jmenos1.append(Jmeno("Zbyšek", 1, []))
        self.jmenos1.append(Jmeno("Zdeněk", 1, []))
        self.jmenos1.append(Jmeno("Zikmund", 1, []))

        #
        self.jmenos2.append(Jmeno("Adéla", 2, []))
        self.jmenos2.append(Jmeno("Alena", 2, []))
        self.jmenos2.append(Jmeno("Alice", 2, []))
        self.jmenos2.append(Jmeno("Anežka", 2, []))
        self.jmenos2.append(Jmeno("Barbora", 2, []))
        self.jmenos2.append(Jmeno("Blanka", 2, []))
        self.jmenos2.append(Jmeno("Božena", 2, []))
        self.jmenos2.append(Jmeno("Dagmar", 2, []))
        self.jmenos2.append(Jmeno("Daniela", 2, []))
        self.jmenos2.append(Jmeno("Dita", 2, []))
        self.jmenos2.append(Jmeno("Dominika", 2, []))
        self.jmenos2.append(Jmeno("Drahomíra", 2, []))
        self.jmenos2.append(Jmeno("Edita", 2, []))
        self.jmenos2.append(Jmeno("Eliška", 2, []))
        self.jmenos2.append(Jmeno("Eliška", 2, []))
        self.jmenos2.append(Jmeno("Eva", 2, []))
        self.jmenos2.append(Jmeno("Gabriela", 2, []))
        self.jmenos2.append(Jmeno("Hana", 2, []))
        self.jmenos2.append(Jmeno("Helena", 2, []))
        self.jmenos2.append(Jmeno("Ilona", 2, []))
        self.jmenos2.append(Jmeno("Ingrid", 2, []))
        self.jmenos2.append(Jmeno("Ivana", 2, []))
        self.jmenos2.append(Jmeno("Iveta", 2, []))
        self.jmenos2.append(Jmeno("Jana", 2, []))
        self.jmenos2.append(Jmeno("Jarmila", 2, []))
        self.jmenos2.append(Jmeno("Jolana", 2, []))
        self.jmenos2.append(Jmeno("Kamila", 2, []))
        self.jmenos2.append(Jmeno("Karolína", 2, []))
        self.jmenos2.append(Jmeno("Kateřina", 2, []))
        self.jmenos2.append(Jmeno("Klára", 2, []))
        self.jmenos2.append(Jmeno("Kristýny", 2, []))
        self.jmenos2.append(Jmeno("Květa", 2, []))
        self.jmenos2.append(Jmeno("Lenka", 2, []))
        self.jmenos2.append(Jmeno("Leona", 2, []))
        self.jmenos2.append(Jmeno("Lucie", 2, []))
        self.jmenos2.append(Jmeno("Magda", 2, []))
        self.jmenos2.append(Jmeno("Marie", 2, ["Maruška", "Majka", "Mary"]))
        self.jmenos2.append(Jmeno("Michaela", 2, []))
        self.jmenos2.append(Jmeno("Monika", 2, []))
        self.jmenos2.append(Jmeno("Olga", 2, []))
        self.jmenos2.append(Jmeno("Patricie", 2, []))
        self.jmenos2.append(Jmeno("Pavlína", 2, []))
        self.jmenos2.append(Jmeno("Petra", 2, []))
        self.jmenos2.append(Jmeno("Radana", 2, []))
        self.jmenos2.append(Jmeno("Radka", 2, []))
        self.jmenos2.append(Jmeno("Rebeka", 2, []))
        self.jmenos2.append(Jmeno("Renata", 2, []))
        self.jmenos2.append(Jmeno("Romana", 2, []))
        self.jmenos2.append(Jmeno("Růžena", 2, []))
        self.jmenos2.append(Jmeno("Sára", 2, []))
        self.jmenos2.append(Jmeno("Silvie", 2, []))
        self.jmenos2.append(Jmeno("Soňa", 2, []))
        self.jmenos2.append(Jmeno("Světlana", 2, []))
        self.jmenos2.append(Jmeno("Šárka", 2, []))
        self.jmenos2.append(Jmeno("Štěpánka", 2, []))
        self.jmenos2.append(Jmeno("Věra", 2, []))
        self.jmenos2.append(Jmeno("Veronika", 2, []))
        self.jmenos2.append(Jmeno("Vladimíra", 2, []))
        self.jmenos2.append(Jmeno("Yvona", 2, []))
        self.jmenos2.append(Jmeno("Zdenka", 2, []))
        self.jmenos2.append(Jmeno("Zita", 2, []))
        self.jmenos2.append(Jmeno("Zuzana", 2, []))
        self.jmenos2.append(Jmeno("Žaneta", 2, []))
